@@ -216,16 +216,6 @@ impl BinaryKey for String {
         self.size()
     }
 
-    #[cfg(feature = "yolo")]
-    #[allow(unsafe_code)]
-    fn read(buffer: &[u8]) -> Self::Owned {
-        // SAFETY:
-        // As with other `BinaryKey` implementations, we assume that data read by the key
-        // is trusted, i.e., was created by a previous call to `write()`.
-        unsafe { std::str::from_utf8_unchecked(buffer).to_string() }
-    }
-
-    #[cfg(not(feature = "yolo"))]
     fn read(buffer: &[u8]) -> Self::Owned {
         const ERROR_MSG: &str = "Error reading UTF-8 string from the database. \
              Probable reason is data schema mismatch; for example, data was written to \
@@ -511,7 +501,6 @@ mod tests {
     }
 
     #[test]
-    #[cfg(not(feature = "yolo"))]
     #[should_panic(expected = "Error reading UTF-8 string")]
     fn test_str_key_error() {
         let buffer = &[0xfe_u8, 0xfd];
